Dimens class
@author lzj
@since 2022/6/13 15:20
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- bottomIconSize → double
-
bottomNavigationBar Icon 尺寸
no setter
- dividerThickness → double
-
分割线厚度
no setter
- listHorizontalPadding → double
-
列表横向内边距(12.w)
no setter
- roundCornerRadius → double
-
图标\图⽚\卡⽚\输⼊框\弹窗等 背景圆角半径 (5.w)
no setter
- verticalDividerHeight → double
-
纵向分割线高度
no setter
Constants
- designSize → const Size
- 设计稿尺寸(378 * 812)