LightColors class
@author lzj
@since 2022/6/13 14:56
默认主题颜色
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- background → const Color
- body → const Color
- card → const Color
- darknessText → const Color
- defaultPageBorderColor → const Color
- defaultPageTextColor → const Color
- error → const Color
- info → const Color
- primary → const Color
- sup1 → const Color
- sup2 → const Color
- sup3 → const Color
- sup4 → const Color
- supBody → const Color
- supTitle → const Color
- textColor70 → const Color
- title → const Color
- warn → const Color