TextStyles class

@author lzj

@since 2022/6/13 16:26

默认主题字体样式

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

appBarTitle TextStyle
appBar标题样式
final
bodyLarge TextStyle
内容(大字体)
final
bodyMedium TextStyle
内容(中字体)
final
bodySmall TextStyle
内容(小字体)
final
tabLabel TextStyle
Tab选中时标题样式
final
tabUnselectedLabel TextStyle
Tab未选中时标题样式
final
titleLarge TextStyle
大标题
final
titleMedium TextStyle
中标题
final
titleSmall TextStyle
小标题
final